@@ -1,4 +1,4 @@
-/*Afterstep phone bill monitor.
+ /*Afterstep phone bill monitor.
 
 	Author: Pedro Moleiro (moleiro@ip.pt)
 
@@ -110,6 +110,7 @@ char    *active_interface = "ppp0";
 
 FILE 	*fp; 
 
+pid_t  	conf_child = 0;
 pid_t  	stop_child = 0;
 pid_t  	start_child = 0;   
  
@@ -131,6 +132,8 @@ long            ppptime;
 void usage(void);
 void Version(void);
 void aspbm_routine(int, char **);
+void DrawClock(int, int, int); 
+void DrawDate(int, int, int); 
 void DrawTime(int, int, int, int); 
 void DrawPulse(int, int);
 void DrawSpeed(long, int);
@@ -264,8 +267,8 @@ void aspbm_routine(int argc, char **argv) {
 	char 			*stringlog;
         	
 	XEvent                  Event;  	
-        time_t          	logtime;
-        struct tm       	*mytime;
+        time_t          	logtime, p_curr_time;
+        struct tm       	*mytime, *p_time;
 	
 	/* rc keys */
 
@@ -352,9 +355,11 @@ void aspbm_routine(int argc, char **argv) {
 
 	defaults();
 
-	AddMouseRegion(0, 4, 49, 60, 60);
-	AddMouseRegion(1, 4, 4, 60, 28);
-	AddMouseRegion(2, 4, 32, 60, 48);
+	AddMouseRegion(0, 4, 4, 60, 22);
+	AddMouseRegion(1, 35, 51, 47, 60);
+	AddMouseRegion(2, 48, 51, 60, 60);
+	AddMouseRegion(3, 4, 51, 34, 60);
+	AddMouseRegion(4, 4, 32, 60, 45);
 
         start_time = 0;
 	pulsestart_time = 0;
@@ -367,6 +372,18 @@ void aspbm_routine(int argc, char **argv) {
 		last_time = curr_time;
                 curr_time = time(0);  
 
+
+/*		mytime->tm_mday, mytime->tm_mon+1, mytime->tm_hour, 
+		mytime->tm_min, mytime->tm_sec, curr_time - start_time, 
+*/
+		time(&p_curr_time);
+		p_time=localtime(&p_curr_time);
+
+		DrawClock(p_time->tm_hour*100+p_time->tm_min, curr_time % 2, 6); 
+		DrawDate(p_time->tm_mday, p_time->tm_mon, p_time->tm_wday); 
+
+
+
  		i = waitpid(0, &status, WNOHANG);
 		if (i == stop_child && stop_child != 0) {
                         SetLED(LED_POWER,0);
@@ -375,7 +392,7 @@ void aspbm_routine(int argc, char **argv) {
                 }                                                
 		if (i == start_child && start_child != 0) {
                         if (WIFEXITED(status)) {
-				copyXPMArea(4, 150, 56, 14, 4, 110); 
+				copyXPMArea(34, 148, 12, 11, 35, 113); 
                                 SetLED(LED_POWER,0);
                                 start_child = 0;
 				is_con=1;
@@ -456,11 +473,8 @@ void aspbm_routine(int argc, char **argv) {
 				
 				time_on = get_number(time_on);
            			pulse_on = get_number(pulse_on); 	
-				DrawTime(time_on, curr_time % 2, TIME_X, 129); 
 				DrawTime(time_on, curr_time % 2, TIME_X+64, 129); 
-				DrawTime(pulse_on, curr_time % 2, PULSE_X, 129);
 				DrawTime(pulse_on, curr_time % 2, PULSE_X+64, 129);
-				DrawPulse(pulse_counter, TIME_X);  
 				DrawPulse(pulse_counter, TIME_X+64);  
 
 				get_statistics(active_interface, &ppp_recv, &ppp_send, &ppp_rbytes, &ppp_sbytes);  
@@ -493,8 +507,8 @@ void aspbm_routine(int argc, char **argv) {
 					ppp_orbytes = ppp_rbytes;
                                 	ppp_osbytes = ppp_sbytes; 
 
-					DrawStats(&ppp_history[0][0], PPP_STATS_HIS, 18, 5, 58);
-					DrawSpeed( ppp_history[PPP_STATS_HIS][0]/updaterate , 32);
+					DrawStats(&ppp_history[0][0], PPP_STATS_HIS, 14, 5, 108);
+					DrawSpeed( ppp_history[PPP_STATS_HIS][0]/updaterate , 115);
 
                                 	for (j=1; j<PPP_STATS_HIS+1; j++) {
                                         	ppp_history[j-1][0] = ppp_history[j][0];
@@ -548,14 +562,12 @@ void aspbm_routine(int argc, char **argv) {
 				sprintf(local_ip, "\n"); 
 				sprintf(server_ip, "\n"); 
 
- 				DrawTime(0, is_blink, TIME_X, 129);
  				DrawTime(0, is_blink, TIME_X+64, 129);
-                                DrawTime(0, is_blink, PULSE_X, 129);
                                 DrawTime(0, is_blink, PULSE_X+64, 129);
-                                DrawPulse(0, TIME_X);
                                 DrawPulse(0, TIME_X+64);
-				DrawStats(&ppp_history[0][0], PPP_STATS_HIS, 18, 5, 58);
-				DrawSpeed( ppp_history[PPP_STATS_HIS][0]/updaterate , 32);      
+				DrawStats(&ppp_history[0][0], PPP_STATS_HIS, 14, 5, 108);
+				DrawSpeed( ppp_history[PPP_STATS_HIS][0]/updaterate , 115);      
+
 				pulse_time = check_pulse();
 				
 			}
@@ -608,28 +620,65 @@ void aspbm_routine(int argc, char **argv) {
 				case ButtonPress:
 					XSetInputFocus(display, win, RevertToNone, CurrentTime);  
 					imouse = GetMouseRegion(Event.xbutton.x, Event.xbutton.y);
-                       			if (Event.xbutton.button == Button1) {
+					if (Event.xbutton.button == Button1) {
 			         		switch (imouse) {
-						case 0: 
-							if (!iswarnpop) {
-								if (stat_cur==1) {
-									if (start_child==0) {
-										start_child = execCommand(con_startrc);
-										if (start_child) fprintf(stderr,"No start command '%s'\n",con_startrc);
-						 				copyXPMArea(4, 165, 56, 14, 4, 110); 
+						case 1:
+						if (!iswarnpop ) {
+							if (stat_cur==1) {
+								if (start_child==0) {
+									start_child = execCommand(con_startrc);
+									if (!start_child) {
+										fprintf(stderr,"No start command '%s'\n",con_startrc);
+									}else{
+						 				copyXPMArea(3, 148, 12, 11, 35, 113); 
 										is_con=1;
 										SetLED(LED_WAIT,1);
-									}else{
-										if (stop_child==0 && start_child>0) {
-											stop_child = execCommand(con_stoprc);
-	 										if (stop_child) fprintf(stderr,"No stop command '%s'\n",con_stoprc);
-	  					 					copyXPMArea(4, 150, 56, 14, 4, 110); 
-											is_con=0;
-											SetLED(LED_WAIT,1);
-										}
 									}
 								}
 							}
+						}
+						break;
+						}
+					}
+
+					XSetInputFocus(display, win, RevertToNone, CurrentTime);  
+					imouse = GetMouseRegion(Event.xbutton.x, Event.xbutton.y);
+					if (Event.xbutton.button == Button1) {
+			         		switch (imouse) {
+						case 2: 
+						if (!iswarnpop ) {
+							if (stat_cur==1) {
+								if (stop_child==0 && start_child>0) {
+									stop_child = execCommand(con_stoprc);
+	 								if (!stop_child) {
+										fprintf(stderr,"No stop command '%s'\n",con_stoprc);
+	  					 			}else {
+										copyXPMArea(34, 148, 12, 11, 35, 113); 
+										is_con=0;
+										SetLED(LED_WAIT,1);
+										stop_child = 0;
+										start_child = 0;
+									}
+								}
+							}
+						}
+						break;
+						}
+					}
+
+					XSetInputFocus(display, win, RevertToNone, CurrentTime);  
+					imouse = GetMouseRegion(Event.xbutton.x, Event.xbutton.y);
+					if (Event.xbutton.button == Button1) {
+			         		switch (imouse) {
+						case 3: 
+						if (!stillonline(active_interface)) {
+							if (stat_cur==1) {
+								conf_child = execCommand("aspbm_conf");
+	 							if (!conf_child) {
+									fprintf(stderr,"No configuration command '%s'\n",con_stoprc);
+								}
+							}
+						}
 						break;
 						}
 					}
@@ -638,21 +687,15 @@ void aspbm_routine(int argc, char **argv) {
 					imouse = GetMouseRegion(Event.xbutton.x, Event.xbutton.y);
                        			if (Event.xbutton.button == Button1) {
 			         		switch (imouse) {
-						case 2: 
-							if (!iswarnpop) {
-								if (stat_cur==0) {
-									pop(bytes_in, bytes_out, cost,atime,acost,actcost,csymbol, cposition);
-									ispopup = 1;
-								}
-							}
+						case 4: 
 							if (!iswarnpop) {
 								if (stat_cur==1) {
 									pop(bytes_in, bytes_out, cost, atime, acost, actcost, csymbol, cposition);
 									ispopup = 1;
 								}
 							}
-						case 1: 
-							if (imouse == 1) {
+						case 0: 
+							if (imouse == 0) {
 								if (stat_cur == 1) {
 									Xmask = 0;
                         	                        		setMaskXY(0, 0);
@@ -726,6 +769,52 @@ void DrawStats(int *his, int num, int size, int x_left, int y_bottom) {
         }                     
 }                        
 
+  /*************/
+ /* DrawClock */
+/*************/
+
+void DrawClock(int i, int j, int posy) {
+
+        int	div = 1000;
+
+        copyXPMArea(51, 162+((i / div)%10)*14, 8, 13, 10, posy);
+        div = div /10;
+        copyXPMArea(51, 162+((i / div)%10)*14, 8, 13, 20, posy);
+
+        if (j)
+                copyXPMArea(58, 148, 2, 13, 30, posy);
+        else
+                copyXPMArea(60, 148, 2, 13, 30, posy);
+
+        div = div /10;
+        copyXPMArea(51, 162+((i / div)%10)*14, 8, 13, 35, posy);
+        div = div /10;
+        copyXPMArea(51, 162+((i / div)%10)*14, 8, 13, 45, posy);
+}                                                  
+
+
+  /************/
+ /* DrawDate */
+/************/
+
+void DrawDate(int i, int j, int w_day) {
+
+int     div = 10;
+
+        copyXPMArea(0, 162+w_day*8, 17, 7, 24, 27);
+
+if (((i / div)%10)==0) {
+        div = div /10;
+        copyXPMArea(40, 162+((i / div)%10)*14, 8, 13, 28, 36);
+}else{
+        copyXPMArea(40, 162+((i / div)%10)*14, 8, 13, 24, 36);
+        div = div /10;
+        copyXPMArea(40, 162+((i / div)%10)*14, 8, 13, 33, 36);
+}
+
+        copyXPMArea(20, 162+j*8, 17, 7, 24, 52);
+}
+
   /************/
  /* DrawTime */
 /************/
@@ -774,6 +863,7 @@ void DrawSpeed(long i,int posy) {
 int 	k = 1000;
 int	dig1=0,dig2=0,dig3=0,dig4=0;
 
+if (i<10000) {
 	dig1=(i / k)%10;
 	k = k /10;
 	dig2=(i / k)%10;
@@ -782,10 +872,23 @@ int	dig1=0,dig2=0,dig3=0,dig4=0;
 	k = k /10;
 	dig4=(i / k)%10;
         	
-	copyXPMArea(6*dig1+1, 129, 5, 7, 21, posy);
-        copyXPMArea(6*dig2+1, 129, 5, 7, 27, posy);
-        copyXPMArea(6*dig3+1, 129, 5, 7, 33, posy);
-        copyXPMArea(6*dig4+1, 129, 5, 7, 40, posy);
+	copyXPMArea(6*dig1+1, 129, 5, 7, 7, posy);
+        copyXPMArea(6*dig2+1, 129, 5, 7, 13, posy);
+        copyXPMArea(6*dig3+1, 129, 5, 7, 19, posy);
+        copyXPMArea(6*dig4+1, 129, 5, 7, 25, posy);
+}else{
+	i=i*10/1024;
+        dig1=(i / k)%10;
+        k = k /10;
+        dig2=(i / k)%10;
+        k = k /10;
+        dig3=(i / k)%10;
+
+        copyXPMArea(6*dig1+1, 129, 5, 7, 7, posy);
+        copyXPMArea(6*dig2+1, 129, 5, 7, 13, posy);
+        copyXPMArea(6*dig3+1, 129, 5, 7, 19, posy);
+        copyXPMArea(42, 139, 5, 7, 25, posy);       
+}
 }               
 
   /***************/
@@ -880,18 +983,19 @@ void get_ppp_stats(struct ppp_stats *cur) {
 void defaults() {
 
 char *namefont;
+int lixo=0;
 
 	/* Phone Rules */
 
-	rule(sunday,1);
-	rule(monday,2);
-	rule(tuesday,3);
-	rule(wednesday,4);
-	rule(thursday,5);
-	rule(friday,6);
-	rule(saturday,7);
-	rule(default0,8);
-	hrule(holyday);
+	lixo=rule(sunday,1);
+	lixo=rule(monday,2);
+	lixo=rule(tuesday,3);
+	lixo=rule(wednesday,4);
+	lixo=rule(thursday,5);
+	lixo=rule(friday,6);
+	lixo=rule(saturday,7);
+	lixo=rule(default0,8);
+	lixo=hrule(holyday);
 
 	pulse_time = check_pulse();
         
@@ -1013,6 +1117,8 @@ aux2 = phone_rules[wd].to_h*100+phone_rules[wd].to_m;
 
 i = phone_rules[8].use;
 pulse_cost=phone_rules[8].at;
+acost=phone_rules[8].fat;
+atime=phone_rules[8].first; 
 
 if ( (aux > (aux1 - 1)) && (aux <= aux2) ) {
         i = phone_rules[wd].use;
@@ -1098,38 +1204,38 @@ void SetLED(int led, int on) {
         switch (led) {
         case LED_WAIT:
 		if (on) {
-			copyXPMArea(LED_WTE_X, LED_WTE_Y, LED_SZE_X, LED_SZE_Y,  LED_PWR_X, LED_PWR_Y);
-			copyXPMArea(LED_WTE_X, LED_WTE_Y, LED_SZE_X, LED_SZE_Y,  LED_PWR_X, LED_PWR_Y+64);
+/*			copyXPMArea(LED_WTE_X, LED_WTE_Y, LED_SZE_X, LED_SZE_Y,  LED_PWR_X, LED_PWR_Y);
+*/			copyXPMArea(LED_WTE_X, LED_WTE_Y, LED_SZE_X, LED_SZE_Y,  LED_PWR_X, LED_PWR_Y+64);
 		} else {
-			copyXPMArea(LED_OFF_X, LED_OFF_Y, LED_SZE_X, LED_SZE_Y,  LED_PWR_X, LED_PWR_Y);
-			copyXPMArea(LED_OFF_X, LED_OFF_Y, LED_SZE_X, LED_SZE_Y,  LED_PWR_X, LED_PWR_Y+64);
+/*			copyXPMArea(LED_OFF_X, LED_OFF_Y, LED_SZE_X, LED_SZE_Y,  LED_PWR_X, LED_PWR_Y);
+*/			copyXPMArea(LED_OFF_X, LED_OFF_Y, LED_SZE_X, LED_SZE_Y,  LED_PWR_X, LED_PWR_Y+64);
 		}
                 break;
         case LED_POWER:
 		if (on) {
-			copyXPMArea(LED_ON_X, LED_ON_Y, LED_SZE_X, LED_SZE_Y,  LED_PWR_X, LED_PWR_Y);
-			copyXPMArea(LED_ON_X, LED_ON_Y, LED_SZE_X, LED_SZE_Y,  LED_PWR_X, LED_PWR_Y+64);
+/*			copyXPMArea(LED_ON_X, LED_ON_Y, LED_SZE_X, LED_SZE_Y,  LED_PWR_X, LED_PWR_Y);
+*/			copyXPMArea(LED_ON_X, LED_ON_Y, LED_SZE_X, LED_SZE_Y,  LED_PWR_X, LED_PWR_Y+64);
 		} else {
-			copyXPMArea(LED_OFF_X, LED_OFF_Y, LED_SZE_X, LED_SZE_Y,  LED_PWR_X, LED_PWR_Y);
-			copyXPMArea(LED_OFF_X, LED_OFF_Y, LED_SZE_X, LED_SZE_Y,  LED_PWR_X, LED_PWR_Y+64);
+/*			copyXPMArea(LED_OFF_X, LED_OFF_Y, LED_SZE_X, LED_SZE_Y,  LED_PWR_X, LED_PWR_Y);
+*/			copyXPMArea(LED_OFF_X, LED_OFF_Y, LED_SZE_X, LED_SZE_Y,  LED_PWR_X, LED_PWR_Y+64);
 		}
                 break;
         case LED_RX:
                 if (on) {
-			copyXPMArea(LED_ON_X, LED_ON_Y, LED_SZE_X, LED_SZE_Y,  LED_RCV_X, LED_RCV_Y);
-			copyXPMArea(LED_ON_X, LED_ON_Y, LED_SZE_X, LED_SZE_Y,  LED_RCV_X, LED_RCV_Y+64);
+/*			copyXPMArea(LED_ON_X, LED_ON_Y, LED_SZE_X, LED_SZE_Y,  LED_RCV_X, LED_RCV_Y);
+*/			copyXPMArea(LED_ON_X, LED_ON_Y, LED_SZE_X, LED_SZE_Y,  LED_RCV_X, LED_RCV_Y+64);
 		} else {
-			copyXPMArea(LED_OFF_X, LED_OFF_Y, LED_SZE_X, LED_SZE_Y,  LED_RCV_X, LED_RCV_Y);
-			copyXPMArea(LED_OFF_X, LED_OFF_Y, LED_SZE_X, LED_SZE_Y,  LED_RCV_X, LED_RCV_Y+64);
+/*			copyXPMArea(LED_OFF_X, LED_OFF_Y, LED_SZE_X, LED_SZE_Y,  LED_RCV_X, LED_RCV_Y);
+*/			copyXPMArea(LED_OFF_X, LED_OFF_Y, LED_SZE_X, LED_SZE_Y,  LED_RCV_X, LED_RCV_Y+64);
 		}
                 break;
         case LED_TX:
                 if (on) {
-			copyXPMArea(LED_ON_X, LED_ON_Y, LED_SZE_X, LED_SZE_Y,  LED_SND_X, LED_SND_Y);
-			copyXPMArea(LED_ON_X, LED_ON_Y, LED_SZE_X, LED_SZE_Y,  LED_SND_X, LED_SND_Y+64);
+/*			copyXPMArea(LED_ON_X, LED_ON_Y, LED_SZE_X, LED_SZE_Y,  LED_SND_X, LED_SND_Y);
+*/			copyXPMArea(LED_ON_X, LED_ON_Y, LED_SZE_X, LED_SZE_Y,  LED_SND_X, LED_SND_Y+64);
 		} else {
-			copyXPMArea(LED_OFF_X, LED_OFF_Y, LED_SZE_X, LED_SZE_Y,  LED_SND_X, LED_SND_Y);
-			copyXPMArea(LED_OFF_X, LED_OFF_Y, LED_SZE_X, LED_SZE_Y,  LED_SND_X, LED_SND_Y+64);
+/*			copyXPMArea(LED_OFF_X, LED_OFF_Y, LED_SZE_X, LED_SZE_Y,  LED_SND_X, LED_SND_Y);
+*/			copyXPMArea(LED_OFF_X, LED_OFF_Y, LED_SZE_X, LED_SZE_Y,  LED_SND_X, LED_SND_Y+64);
 		}
                 break;
         }                                         
